forcats (in python)
===================

This is a port of the popular R package forcats to python.

**NOTE:** I am in the process of moving the forcats module from [machow/siuba](https://github.com/machow/siuba) to here.
In the meantime, you can install and use it from there.

First, install siuba:

```
pip install siuba
```

Then, you can import forcats using...

```
from siuba.dply.forcats import fct_lump, fct_reorder          # etc..
```
